@@ -4,15 +4,20 @@ implement these models with fields and and methods to be compatible with the
 views in :attr:`provider.views`.
 """
 
-from datetime import datetime
 from django.db import models
 from django.conf import settings
 from .. import constants
 from ..constants import CLIENT_TYPES
 from ..utils import short_token, long_token, get_token_expiry
 from ..utils import get_code_expiry
+from ..utils import now
 from .managers import AccessTokenManager
 
+try:
+    from django.utils import timezone
+except ImportError:
+    timezone = None
+
 AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 
 
@@ -104,11 +109,24 @@ class AccessToken(models.Model):
     def __unicode__(self):
         return self.token
 
-    def get_expire_delta(self):
+    def get_expire_delta(self, reference=None):
         """
         Return the number of seconds until this token expires.
         """
-        return (self.expires - datetime.now()).seconds
+        if reference is None:
+            reference = now()
+        expiration = self.expires
+
+        if timezone:
+            if timezone.is_aware(reference) and timezone.is_naive(expiration):
+                # MySQL doesn't support timezone for datetime fields
+                # so we assume that the date was stored in the UTC timezone
+                expiration = timezone.make_aware(expiration, timezone.utc)
+            elif timezone.is_naive(reference) and timezone.is_aware(expiration):
+                reference = timezone.make_aware(reference, timezone.utc)
+
+        timedelta = expiration - reference
+        return timedelta.days*86400 + timedelta.seconds
 
 
 class RefreshToken(models.Model):
