@@ -1,5 +1,6 @@
 import json
 import urlparse
+import datetime
 from django.http import QueryDict
 from django.conf import settings
 from django.core.urlresolvers import reverse
@@ -9,6 +10,7 @@ from django.contrib.auth.models import User
 from .. import constants, scope
 from ..compat import skipIfCustomUser
 from ..templatetags.scope import scopes
+from ..utils import now as date_now
 from .forms import ClientForm
 from .models import Client, Grant, AccessToken
 from .backends import BasicClientBackend, RequestParamsClientBackend
@@ -197,6 +199,15 @@ class AuthorizationTest(BaseOAuth2TestCase):
 class AccessTokenTest(BaseOAuth2TestCase):
     fixtures = ['test_oauth2.json']
 
+    def test_access_token_get_expire_delta_value(self):
+        user = self.get_user()
+        client = self.get_client()
+        token = AccessToken.objects.create(user=user, client=client)
+        now = date_now()
+        default_expiration_timedelta = constants.EXPIRE_DELTA
+        current_expiration_timedelta = datetime.timedelta(seconds=token.get_expire_delta(reference=now))
+        self.assertTrue(abs(current_expiration_timedelta - default_expiration_timedelta) <= datetime.timedelta(seconds=1))
+
     def test_fetching_access_token_with_invalid_client(self):
         self.login()
         self._login_and_authorize()
@@ -262,6 +273,16 @@ class AccessTokenTest(BaseOAuth2TestCase):
         self.assertEqual('unsupported_grant_type', json.loads(response.content)['error'],
             response.content)
 
+    def test_fetching_single_access_token(self):
+        constants.SINGLE_ACCESS_TOKEN = True
+
+        result1 = self._login_authorize_get_token()
+        result2 = self._login_authorize_get_token()
+
+        self.assertEqual(result1['access_token'], result2['access_token'])
+
+        constants.SINGLE_ACCESS_TOKEN = False
+
     def test_fetching_access_token_multiple_times(self):
         self._login_authorize_get_token()
         code = self.get_grant().code
