@@ -1,11 +1,12 @@
 from django import template
-from provider import scope
+from .. import scope
 
 register = template.Library()
 
+
 @register.filter
 def scopes(scope_int):
-    """ 
+    """
     Wrapper around :attr:`provider.scope.names` to turn an int into a list
     of scope names in templates.
     """
